<?php

namespace Litecms\Backdoor\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Backdoor\Http\Requests\InstructorRequest;
use Litecms\Backdoor\Models\Instructor;

/**
 * Admin web controller class.
 */
class InstructorWorkflowController extends BaseController
{

    /**
     * Workflow controller function for instructor.
     *
     * @param Model   $instructor
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(InstructorRequest $request, Instructor $instructor, $step)
    {

        try {

            $instructor->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('backdoor::instructor.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/instructor/instructor/' . $instructor->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/instructor/instructor/' . $instructor->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for instructor.
     *
     * @param Model   $instructor
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Instructor $instructor, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $instructor->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('backdoor::instructor.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.instructor.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.instructor.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.instructor.message', $data)->render();

        }

    }
}
