<?php

namespace Litecms\Backdoor\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Backdoor\Interfaces\SupplierRepositoryInterface;

class SupplierPublicController extends BaseController
{
    // use SupplierWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Supplier\Interfaces\SupplierRepositoryInterface $supplier
     *
     * @return type
     */
    public function __construct(SupplierRepositoryInterface $supplier)
    {
        $this->repository = $supplier;
        parent::__construct();
    }

    /**
     * Show supplier's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $suppliers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$backdoor::$supplier.names'))
            ->view('$backdoor::public.supplier.index')
            ->data(compact('$suppliers'))
            ->output();
    }

    /**
     * Show supplier's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $suppliers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$backdoor::$supplier.names'))
            ->view('$backdoor::public.supplier.index')
            ->data(compact('$suppliers'))
            ->output();
    }

    /**
     * Show supplier.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $supplier = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$supplier->name . trans('$backdoor::$supplier.name'))
            ->view('$backdoor::public.supplier.show')
            ->data(compact('$supplier'))
            ->output();
    }

}
