<?php

namespace Litecms\Backdoor\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Backdoor\Http\Requests\SupplierRequest;
use Litecms\Backdoor\Models\Supplier;

/**
 * Admin web controller class.
 */
class SupplierWorkflowController extends BaseController
{

    /**
     * Workflow controller function for supplier.
     *
     * @param Model   $supplier
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SupplierRequest $request, Supplier $supplier, $step)
    {

        try {

            $supplier->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('backdoor::supplier.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/supplier/supplier/' . $supplier->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/supplier/supplier/' . $supplier->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for supplier.
     *
     * @param Model   $supplier
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Supplier $supplier, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $supplier->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('backdoor::supplier.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.supplier.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.supplier.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('backdoor::admin.supplier.message', $data)->render();

        }

    }
}
