<?php

namespace Litecms\Backdoor\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Backdoor\Models\Instructor;

class InstructorPolicy
{

    /**
     * Determine if the given user can view the instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function view(UserPolicy $user, Instructor $instructor)
    {
        if ($user->canDo('backdoor.instructor.view') && $user->isAdmin()) {
            return true;
        }

        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('backdoor.instructor.create');
    }

    /**
     * Determine if the given user can update the given instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function update(UserPolicy $user, Instructor $instructor)
    {
        if ($user->canDo('backdoor.instructor.edit') && $user->isAdmin()) {
            return true;
        }

        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Instructor $instructor)
    {
        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Instructor $instructor)
    {
        if ($user->canDo('backdoor.instructor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given instructor.
     *
     * @param UserPolicy $user
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Instructor $instructor)
    {
        if ($user->canDo('backdoor.instructor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
