<?php

namespace Litecms\Backdoor\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Backdoor\Models\Supplier;

class SupplierPolicy
{

    /**
     * Determine if the given user can view the supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function view(UserPolicy $user, Supplier $supplier)
    {
        if ($user->canDo('backdoor.supplier.view') && $user->isAdmin()) {
            return true;
        }

        return $supplier->user_id == user_id() && $supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can create a supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('backdoor.supplier.create');
    }

    /**
     * Determine if the given user can update the given supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function update(UserPolicy $user, Supplier $supplier)
    {
        if ($user->canDo('backdoor.supplier.edit') && $user->isAdmin()) {
            return true;
        }

        return $supplier->user_id == user_id() && $supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Supplier $supplier)
    {
        return $supplier->user_id == user_id() && $supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Supplier $supplier)
    {
        if ($user->canDo('backdoor.supplier.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given supplier.
     *
     * @param UserPolicy $user
     * @param Supplier $supplier
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Supplier $supplier)
    {
        if ($user->canDo('backdoor.supplier.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
