<?php

namespace Litecms\Backdoor\Providers;

use Illuminate\Support\ServiceProvider;

class BackdoorServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'backdoor');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'backdoor');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.backdoor', function ($app) {
            return $this->app->make('Litecms\Backdoor\Backdoor');
        });

        // Bind Supplier to repository
        $this->app->bind(
            'Litecms\Backdoor\Interfaces\SupplierRepositoryInterface',
            \Litecms\Backdoor\Repositories\Eloquent\SupplierRepository::class
        );
        // Bind Instructor to repository
        $this->app->bind(
            'Litecms\Backdoor\Interfaces\InstructorRepositoryInterface',
            \Litecms\Backdoor\Repositories\Eloquent\InstructorRepository::class
        );

        $this->app->register(\Litecms\Backdoor\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Backdoor\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Backdoor\Providers\RouteServiceProvider::class);
                $this->app->register(\Litecms\Backdoor\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.backdoor'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/backdoor.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/backdoor')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/backdoor')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
