<?php

namespace Litecms\Backdoor\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Backdoor\Models\Instructor;

class InstructorAction
{
    /**
     * Perform the complete action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */
    public function complete(Instructor $instructor)
    {
        try {
            $instructor->status = 'complete';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */public function verify(Instructor $instructor)
    {
        try {
            $instructor->status = 'verify';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */public function approve(Instructor $instructor)
    {
        try {
            $instructor->status = 'approve';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */public function publish(Instructor $instructor)
    {
        try {
            $instructor->status = 'publish';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */
    public function archive(Instructor $instructor)
    {
        try {
            $instructor->status = 'archive';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Instructor $instructor
     *
     * @return Instructor
     */
    public function unpublish(Instructor $instructor)
    {
        try {
            $instructor->status = 'unpublish';
            return $instructor->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
