<?php

namespace Litecms\Backdoor\Workflow;

use Litecms\Backdoor\Models\Instructor;
use Validator;

class InstructorValidator
{

    /**
     * Determine if the given instructor is valid for complete status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function complete(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given instructor is valid for verify status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function verify(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given instructor is valid for approve status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function approve(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given instructor is valid for publish status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function publish(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given instructor is valid for archive status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function archive(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given instructor is valid for unpublish status.
     *
     * @param Instructor $instructor
     *
     * @return bool / Validator
     */
    public function unpublish(Instructor $instructor)
    {
        return Validator::make($instructor->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
