<?php

namespace Litecms\Backdoor\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Backdoor\Models\Supplier;

class SupplierAction
{
    /**
     * Perform the complete action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */
    public function complete(Supplier $supplier)
    {
        try {
            $supplier->status = 'complete';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */public function verify(Supplier $supplier)
    {
        try {
            $supplier->status = 'verify';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */public function approve(Supplier $supplier)
    {
        try {
            $supplier->status = 'approve';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */public function publish(Supplier $supplier)
    {
        try {
            $supplier->status = 'publish';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */
    public function archive(Supplier $supplier)
    {
        try {
            $supplier->status = 'archive';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Supplier $supplier
     *
     * @return Supplier
     */
    public function unpublish(Supplier $supplier)
    {
        try {
            $supplier->status = 'unpublish';
            return $supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
