<?php

namespace Litecms\Backdoor\Workflow;

use Litecms\Backdoor\Models\Supplier;
use Validator;

class SupplierValidator
{

    /**
     * Determine if the given supplier is valid for complete status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function complete(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given supplier is valid for verify status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function verify(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given supplier is valid for approve status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function approve(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given supplier is valid for publish status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function publish(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given supplier is valid for archive status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function archive(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given supplier is valid for unpublish status.
     *
     * @param Supplier $supplier
     *
     * @return bool / Validator
     */
    public function unpublish(Supplier $supplier)
    {
        return Validator::make($supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
